dl.portlet-static-drag-drop dd.portletItem p {
    text-align: center;
}


dl.portlet-static-drag-drop .state-hover {
    background-color: #fbf9ee;
}

dl.portlet-static-drag-drop .state-hover dd.portletItem {
    background-color: #fbf9ee;
}

#thumbnail-view.state-hover {
    background-color: #fbf9ee;
}


dl.portlet-static-drag-drop .border-box {
            box-sizing: border-box;
       -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}

dl.portlet-static-drag-drop .break-word {
    word-wrap: break-word;
}

dl.portlet-static-drag-drop .border-radius {
            border-radius: 4px;
       -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
}

dl.portlet-static-drag-drop #dragdrop-container {
    min-height: 50px;
}


dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container:not(:first-child) {
    margin-top: 0.5em;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container {
    width: 100%;
    border: 1px solid rgba(0,0,0,0.3);
    text-align: left;
    cursor: move;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .thumbnail-wrapper {
    width: 30%;
    float: left;
    padding: 1%;
    text-align: center;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .thumbnail-wrapper img {
    max-width: 98%;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .item-title {
    width: 70%;
    float: left;
    padding: 1%;
    font-size: 90%;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .action-bar {
    width: 100%;
    padding: 3%;
    border-bottom: 1px dotted rgba(0,0,0,0.3);
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .action-bar .fa {
    line-height: 20px;
    font-size: 16px;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .action-bar .delete-item {
    cursor: pointer;
    float: right;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .action-bar .copy-move-item {
    cursor: pointer;
    float: left;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .action-bar input[type="checkbox"] {
    margin-left: 5px;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container .action-bar .loader {
    display: none;
    float: left;
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container.can-not-move-or-copy {
    border-color: #cd0a0a;
    cursor: default;
    opacity: 0.6;
    filter: Alpha(opacity=60);
}
dl.portlet-static-drag-drop dd.portletItem p div.drag-drop-container.can-not-move-or-copy .action-bar .copy-move-item {
    cursor: default;
}

.clear-fix-drag-drop:after, 
.clear-fix-drag-drop::after {
    width: 0;
    height: 0;
    content: '.';
    clear: both;
    display: block;
    padding: 0;
    margin: 0;
    font-size: 0;
}

dl.portlet-static-drag-drop dd.portletItem div.copy-move-container {
    margin-top: 1em;
    width: 100%;
    border: 1px solid rgba(0,0,0,0.3);
}
dl.portlet-static-drag-drop dd.portletItem div.copy-move-container .action-bar {
    width: 50%;
    height: 2em;
    line-height: 2em;
    text-align: center;
    border: none;
    float: left;
    cursor: pointer;
}
dl.portlet-static-drag-drop dd.portletItem div.copy-move-container .action-bar:first-child {
    border-right: 1px solid rgba(0,0,0,0.3);
}
dl.portlet-static-drag-drop dd.portletItem div.copy-move-container .action-bar {
    color: rgba(0,0,0,0.4);
}
dl.portlet-static-drag-drop dd.portletItem div.copy-move-container .action-bar.state-active {
    background-color: #789f09;
    color: #fff;
}
dl.portlet-static-drag-drop dd.portletItem div.copy-move-container .action-bar.state-hover {
    background-color: #b8e33b;
}


.folder-item.ui-draggable.ui-draggable-dragging,
.folder-item.ui-sortable-helper,
.folder-item.ui-draggable-dragging {
    border: 1px solid #ccc;
    /*margin: 4px 8px 4px 0;
    padding: 6px;
    text-align: center;
    width: 128px;
    font-size: 12px;
    line-height: 1.5em;*/
    background-color: rgba(0,0,0,0.2);
    border: 1px solid rgba(0,0,0,0.2);
            border-radius: 4px;
       -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
    padding-left: 0;
    padding-right: 0;
    overflow: hidden;
}

.folder-item.ui-draggable.ui-draggable-dragging .thumbnail,
.folder-item.ui-sortable-helper .thumbnail,
.folder-item.ui-draggable-dragging .thumbnail {
    display: block;
    margin: 0;
    z-index: 9999;
    opacity: 0.6;
    filter: Alpha(opacity=60);
    width: 100%;
    height: 100%
}


.folder-item.ui-draggable.ui-draggable-dragging .thumbnail a[class*="col"],
.folder-item.ui-sortable-helper .thumbnail a[class*="col"],
.folder-item.ui-draggable-dragging .thumbnail a[class*="col"] {
    width: 100%;
    padding: 0;
}


.folder-item.ui-draggable.ui-draggable-dragging .item-title,
.folder-item.ui-sortable-helper .item-title,
.folder-item.ui-draggable-dragging .item-title {
    font-size: 90%;
    /*height: 4.5em;*/
    line-height: 1em;
    overflow: hidden;
}

.folder-item.ui-draggable.ui-draggable-dragging .additional-information-trigger,
.folder-item.ui-sortable-helper .additional-information-trigger,
.folder-item.ui-draggable-dragging .additional-information-trigger {
    display: none;
}

.folder-item.ui-sortable-helper .additional-information { display: none; }
.folder-item.ui-sortable-helper.ui-draggable-dragging:after,
.folder-item.ui-sortable-helper.ui-draggable-dragging::after {
    clear: both;
    content: '.';
    display: block;
    height: 0;
    line-height: 0;
    font-size: 0;
    visibility: hidden;
    padding: 0;
    margin: 0;
}

#thumbnail-view .sorting.placeholder .thumbnail {
    border: 1px solid #fcefa1;
    background-color: #fbf9ee;
    margin-bottom: 20px;
            border-radius: 4px;
       -moz-border-radius: 4px;
    -webkit-border-radius: 4px;
}

#thumbnail-view form[name="folderContentsForm"]::after {
    clear: both;
    content: '.';
    display: block;
    height: 0;
    line-height: 0;
    font-size: 0;
    visibility: hidden;
    padding: 0;
    margin: 0;
}

#delete-container {
    margin-top: 10px;
	font-size: 4em;
	text-align: center;
}
#delete-container.state-active i {
    color: #789f09;
}
#delete-container.state-hover {
    background: none!important;
}
#delete-container.state-hover i {
    color: #cd0a0a;
}






dl.portletAjaxNavigation li.state-hover {
    color: #fff !important;
    background-color: #789f09 !important;
}

dl.portletAjaxNavigation li.state-error {
    color: #fff !important;
    background-color: #cd0a0a !important;
}
#delete-container .icon-trash {
	color: black;
}
